#
# spec file for package scirenderer
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           scirenderer
Version:        1.1.0
Release:        8.1
Summary:        A Java rendering library based on JoGL
License:        CECILL-2.0
Group:          Development/Libraries/Java
URL:            https://gitlab.com/scilab/forge/scirenderer
Source0:        %{name}-%{version}.tar.xz
Patch0:         %{name}-0000-jogl2.0.2.patch
# PATCH-FIX-UPSTREAM scirenderer-fix-compilation-with-jogl-2.3.patch badshah400@gmail.com -- Fix compilation with jogl 2.3.x
Patch1:         scirenderer-fix-compilation-with-jogl-2.3.patch
Patch2:         scirenderer-1.1.0-javadoc.patch
Patch3:         scirenderer-1.1.0-nosourcetarget.patch
BuildRequires:  ant
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  jlatexmath
BuildRequires:  jogl2 >= 2.3
BuildRequires:  jpackage-utils
Requires:       java >= 1.8
Requires:       jpackage-utils
BuildArch:      noarch

%description
SciRenderer is a rendering library based on JoGL. This Java API allows
2-D or 3-D plotting from simple 2-D graph to complex scenes. Independent
library, SciRender is used within Scilab software but is available
for other application and developments.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Libraries/Java

%description javadoc
This package contains the documentation for SciRenderer.

%prep
%setup -q

%patch -P 0 -p1
%patch -P 1 -p1
%patch -P 2 -p1
%patch -P 3 -p1

# Update path according to the openSUSE
tee scirenderer-libs.properties << EOF
jogl2.jar=$(find-jar jogl2)
gluegen2-rt.jar=$(find-jar gluegen2-rt)
jlatexmath.jar=$(find-jar jlatexmath)
EOF

# fix class-path-in-manifest
sed -i '/Class-Path/I d' build.xml

%build
%{ant} \
    -Dant.build.javac.source=1.8 -Dant.build.javac.target=1.8 \
    jar doc

%install
install -Dm 644 jar/%{name}-%{version}.jar %{buildroot}%{_javadir}/%{name}.jar

mkdir -p %{buildroot}%{_javadocdir}/%{name}
cp -pr docs/* %{buildroot}%{_javadocdir}/%{name}
%fdupes -s %{buildroot}%{_javadocdir}/%{name}

%files
%{_javadir}/%{name}.jar
%license COPYING
%doc README CHANGES

%files javadoc
%{_javadocdir}/%{name}

%changelog
* Wed Feb  5 2025 Fridrich Strba <fstrba@suse.com>
- Work around the fact that some arch-dependent defines are not
  defined for noarch builds
* Wed Feb 21 2024 Fridrich Strba <fstrba@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
- Fetch the sources from gitlab mirror since the original link
  does not work any more
* Wed Mar 23 2022 Fridrich Strba <fstrba@suse.com>
- Build with java source and target levels 8
- Added patch:
  * scirenderer-1.1.0-nosourcetarget.patch
    + Do not hardcode source and target levels
* Wed Sep 20 2017 fstrba@suse.com
- Added patch:
  * scirenderer-1.1.0-javadoc.patch
    + use the source and target level 6 consistently in all javac
    and javadoc invocations
    + fix unresolved symbols when generating documentation
- Clean spec files and run fdupes
* Wed Apr 15 2015 badshah400@gmail.com
- Add patch scirenderer-fix-compilation-with-jogl-2.3.patch to
  fix building with jogl2 >= 2.3. Fixes upstream bug
  http://forge.scilab.org/index.php/p/scirenderer/issues/1545/.
* Fri Apr 18 2014 badshah400@gmail.com
- Use full download link for Source tag
- Remove Class-Path from MANIFEST files (fixes an rpmlint warning)
- Do not package the same doc files twice (README, COPYING,
  CHANGES).
* Thu Aug  1 2013 ierturk@ieee.org
- Update to version 1.1.0
- Fix compatibility with jogl2-2.0.2
  * scirenderer-0000-jogl2.0.2.patch
* Sat Dec  1 2012 dmitry_r@opensuse.org
- Initial package
- Version 1.0.2
